#Code for Figure S3 of "A universal, empirically derived proxy for coral bleaching susceptibility"

library(lmerTest)
library(emmeans)
library(sjPlot)
library(ggplot2)

#setwd to source file location

CBASS_PR<-read.csv("CBASS_PR_clean.csv")
View(CBASS_PR)
str(CBASS_PR)

CBASS_PR$Temp<-as.factor(CBASS_PR$Temp)

#Subset data
CBASS_PR_Acr<-subset(CBASS_PR, Species=="Acropora")
CBASS_PR_Por<-subset(CBASS_PR, Species=="Porites")

#### GLMMs for Net photosynthesis and respiration for CBASS ####

#### Acropora Net PS ####
CBASS_Acr_PS<-lmer(NetPS ~ Temp*Site + (1|Geno),data=CBASS_PR_Acr)
sjPlot::plot_model(CBASS_Acr_PS, type="diag")
step(CBASS_Acr_PS, reduce.random = F)

CBASS_Acr_PS_final<-lmer(NetPS ~ Temp + (1|Geno),data=CBASS_PR_Acr)
anova(CBASS_Acr_PS_final)

print(emmeans(CBASS_Acr_PS_final, list(pairwise ~ Temp)), adjust = c("mvt"))

#### Acropora Resp ####
CBASS_Acr_Resp<-lmer(Resp ~ Temp*Site + (1|Geno),data=CBASS_PR_Acr)
sjPlot::plot_model(CBASS_Acr_Resp, type="diag")
step(CBASS_Acr_Resp, reduce.random = F)

CBASS_Acr_Resp_final<-lmer(Resp ~ Temp*Site + (1|Geno),data=CBASS_PR_Acr)
anova(CBASS_Acr_Resp_final)

print(emmeans(CBASS_Acr_Resp_final, list(pairwise ~ Temp|Site)), adjust = c("mvt"))
print(emmeans(CBASS_Acr_Resp_final, list(pairwise ~ Site|Temp)), adjust = c("mvt"))

#### Porites Net PS ####
CBASS_Por_PS<-lmer(NetPS ~ Temp*Site + (1|Geno),data=CBASS_PR_Por)
sjPlot::plot_model(CBASS_Por_PS, type="diag")
step(CBASS_Por_PS, reduce.random = F)

CBASS_Por_PS_final<-lmer(NetPS ~ Temp + (1|Geno),data=CBASS_PR_Por)
anova(CBASS_Por_PS_final)

print(emmeans(CBASS_Por_PS_final, list(pairwise ~ Temp)), adjust = c("mvt"))

#### Porites Resp ####
CBASS_Por_Resp<-lmer(Resp ~ Temp*Site + (1|Geno),data=CBASS_PR_Por)
sjPlot::plot_model(CBASS_Por_Resp, type="diag")
step(CBASS_Por_Resp, reduce.random = F)

CBASS_Por_Resp_final<-lmer(Resp ~ Site + (1|Geno),data=CBASS_PR_Por)
anova(CBASS_Por_Resp_final)

print(emmeans(CBASS_Por_Resp_final, list(pairwise ~ Site)), adjust = c("mvt"))


#########################################################
######### Plot CBASS Net PS + Resp (Figure S3) ##########
#########################################################

NetPS_Plot <- ggplot(data=CBASS_PR, 
                    aes(x=Temp, y=NetPS, label=Temp, fill=Site)) +
  scale_fill_manual(values = c("grey60", "grey30"), name = "Site") +
  stat_boxplot(geom ='errorbar', width = 0.7, lwd=0.7) +
  geom_boxplot(width=0.7, lwd=0.7, fatten=1) +
  expand_limits(y = 0)+
  facet_grid(~Species, space = "free", scales = "free") +
  theme_bw() +
  annotate("segment", x=-Inf, xend=-Inf, y=-Inf, yend=Inf, colour = "black", size=2) +
  theme(line= element_line(size = 1),
        axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(0.2 , "cm"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        strip.background = element_blank(), 
        strip.text.x = element_text(color = "black", size = 18, angle = 0, hjust = 0, vjust = 0.5, family = 'ArialMT', face = 'bold.italic'),
        panel.spacing = unit(3, "lines")) + xlab(label = "Temperature") + ylab(label = "Net photosynthesis (µmol O2 cm-2 h-1)")+
  theme(axis.text.x = element_text(color = "black", size = 12, angle = 0, hjust = .5, vjust = .5, family = 'ArialMT', face = 'bold'),
        axis.text.y = element_text(color = "black", size = 12, angle = 0, hjust = .5, vjust = .5, family = 'ArialMT', face = 'bold'),  
        axis.title.x = element_text(color = "black", size = 15, angle = 0, hjust = .5, vjust = 0, family = 'ArialMT', face = 'bold'),
        axis.title.y = element_text(color = "black", size = 15, angle = 90, hjust = .5, vjust = .5,family = 'ArialMT', face = 'bold'),
        legend.title = element_text(colour="black", size=15, family = 'ArialMT', face = 'bold'),
        legend.text = element_text(colour="black", size=15, family = 'ArialMT', face = 'bold'),
        legend.position="bottom") + scale_y_continuous(limits = c(-0.30,1.2), breaks = c(0.0,0.5,1)) +
        geom_hline(yintercept=0, linetype="dashed", color = "black")
NetPS_Plot

Resp_Plot <- ggplot(data=CBASS_PR, 
                   aes(x=Temp, y=-Resp, label=Temp, fill=Site)) +
  scale_fill_manual(values = c("grey60", "grey30"), name = "Site") +
  stat_boxplot(geom ='errorbar', width = 0.7, lwd=0.7)+
  geom_boxplot(width=0.7, lwd=0.7, fatten=1) +
  expand_limits(y = 0)+
  facet_grid(~Species, space = "free", scales = "free")+ 
  theme_bw() +
  annotate("segment", x=-Inf, xend=-Inf, y=-Inf, yend=Inf, colour = "black", size=2) +
  theme(line= element_line(size = 1),
        axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(0.2 , "cm"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        strip.background = element_blank(), 
        strip.text.x = element_text(color = "black", size = 18, angle = 0, hjust = 0, vjust = 0.5, family = 'ArialMT', face = 'bold.italic'),
        panel.spacing = unit(3, "lines")) + xlab(label = "Temperature") + ylab(label = "Respiration (µmol O2 cm-2 h-1)")+
  theme(axis.text.x = element_text(color = "black", size = 12, angle = 0, hjust = .5, vjust = .5, family = 'ArialMT', face = 'bold'),
        axis.text.y = element_text(color = "black", size = 12, angle = 0, hjust = .5, vjust = .5, family = 'ArialMT', face = 'bold'),  
        axis.title.x = element_text(color = "black", size = 15, angle = 0, hjust = .5, vjust = 0, family = 'ArialMT', face = 'bold'),
        axis.title.y = element_text(color = "black", size = 15, angle = 90, hjust = .5, vjust = .5,family = 'ArialMT', face = 'bold'),
        legend.title = element_text(colour="black", size=15, family = 'ArialMT', face = 'bold'),
        legend.text = element_text(colour="black", size=15, family = 'ArialMT', face = 'bold'),
        legend.position="bottom") + scale_y_continuous(limits = c(0,1.25), breaks = c(0.0,0.3,0.6,0.9,1.2))
Resp_Plot

#END